.nj-avatar{position:relative;width:4rem;height:4rem}.nj-avatar__picture{width:inherit;height:inherit;overflow:hidden;background:#85d0f4 url("data:image/svg+xml;charset=UTF-8,%3Csvg version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' x='0px' y='0px' width='78.8px' height='85px' viewBox='0 0 78.8 85' style='enable-background:new 0 0 78.8 85;' xml:space='preserve'%3E%3Cstyle type='text/css'%3E .st0%7Bfill-rule:evenodd;clip-rule:evenodd;fill:%23009DE9;%7D%0A%3C/style%3E%3Cdefs%3E%3C/defs%3E%3Cpath class='st0' d='M59.2,19.8C59.2,8.9,50.4,0,39.4,0S19.6,8.9,19.6,19.8c0,11,8.9,19.8,19.8,19.8S59.2,30.8,59.2,19.8z M0,64.9 C8.5,77,23,85,39.4,85c16.4,0,30.9-8,39.4-20.1c-0.2-12.4-26.3-19.3-39.4-19.3C26.3,45.6,0.2,52.4,0,64.9z'/%3E%3C/svg%3E%0A") center bottom no-repeat;background-size:81%;border-radius:50%}.nj-avatar__picture img{max-width:100%;vertical-align:unset}.nj-avatar__initials{display:flex;align-items:center;justify-content:center;width:inherit;height:inherit;font-size:1.5rem;color:var(--nj-color-text-background-base);text-transform:uppercase;background:var(--nj-color-base-primary)}.nj-avatar .nj-badge{position:absolute;right:-1px;bottom:-1px;font-weight:400}.nj-avatar:first-child,.nj-avatar+.nj-avatar{margin-right:.5rem}.nj-avatar--sm{width:3rem;height:3rem}.nj-avatar--sm .nj-avatar__initials{font-size:1rem}.nj-avatar--sm .nj-badge{right:-2px}.nj-avatar--lg{width:6rem;height:6rem}.nj-avatar--lg .nj-avatar__initials{font-size:2.25rem}.nj-avatar--lg .nj-badge{right:0;bottom:1px}.nj-avatar[href]:hover{text-decoration:none}.nj-avatar[href]:hover .nj-avatar__picture{box-shadow:0 0 0 2px #009de9}
