.nj-stamp{width:170px;height:170px;border-radius:50%}.nj-stamp__text{font-weight:900;font-family:Lato, sans-serif;font-size:1.75rem}.nj-stamp__overlay{opacity:1;fill:#fff}.nj-stamp--shadow{box-shadow:var(--nj-shadow-level-8-dp)}
