.nj-pagination{--pagination-nav-color: var(--nj-color-text-body);--pagination-background-color-hover: var(--nj-color-base-gray-200);display:flex;margin-top:1rem;padding-left:0;list-style:none}[data-theme="dark"] .nj-pagination,.nj-pagination[data-theme="dark"]{--pagination-nav-color: var(--nj-color-base-primary);--pagination-background-color-hover: var(--nj-color-base-gray-500)}.nj-pagination__nav{color:var(--pagination-nav-color);line-height:2rem}.nj-pagination__item{margin-right:.5rem}.nj-pagination__item--active .nj-pagination__link{z-index:1;color:var(--nj-color-text-body-inverted);background-color:#009de9}.nj-pagination__item--active .nj-pagination__link:hover{color:#fff;background-color:#009de9}.nj-pagination__item--disabled .nj-pagination__link{cursor:default;pointer-events:none}.nj-pagination__item--disabled .nj-pagination__nav{color:#e0e0e0}.nj-pagination__link{position:relative;display:block;width:2rem;height:2rem;color:var(--nj-color-text-body);font-weight:400;line-height:2rem;text-align:center;border-radius:0;font-size:0.875rem;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.2s}.nj-pagination__link:hover,.nj-pagination__link:focus{z-index:2;text-decoration:none;outline:none}.nj-pagination__link:hover{color:var(--nj-color-text-body);background-color:var(--pagination-background-color-hover)}.nj-pagination__link:focus{color:var(--nj-color-text-body-inverted);background-color:#009de9}.nj-pagination__link:focus .nj-pagination__nav{color:var(--nj-color-text-body-inverted)}.nj-pagination__link--prev:hover,.nj-pagination__link--prev:focus,.nj-pagination__link--next:hover,.nj-pagination__link--next:focus{color:#009de9;background:none}.nj-pagination__link--prev:hover .nj-pagination__nav,.nj-pagination__link--prev:focus .nj-pagination__nav,.nj-pagination__link--next:hover .nj-pagination__nav,.nj-pagination__link--next:focus .nj-pagination__nav{color:#009de9}
