/*!

 * Copyright 2013 CreaLibre (Monterrey, MEXICO), all rights reserved.
 * Contact http://www.crealibre.com/ -- mailto:info@crealibre.com

 * organization: Logilab
 * copyright: 2013 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 * contact: https://www.logilab.fr/ -- mailto:contact@logilab.fr
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation, either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>..
 */
/*-----------------------------------*/
/*  NO BOOTSTRAP RELATED CSS HERE    */
/*-----------------------------------*/

/* GENERIC */
/*----------------------------------- */

.hidden {
  display: none;
  visibility: hidden;
}

div#progress {
  display: none
}

.no-margin{
  margin: 0;
}

/* Fixed modal window on mobile resolutions. */
@media screen and (max-width: 480px) {
    div.modal-dialog input,
    div.modal-dialog textarea,
    div.modal-dialog select{
       width: 100%; /* fix inputs size*/
    }
}


ul.list-striped {
 margin-left: 0;
 list-style: none;
}

ul.list-striped li {
 padding: 10px;
 border-bottom: 1px dotted #CCCCCC;
}

ul.list-striped li.even {
 background-color: #F5F5F5;
}

ul.list-striped ul.list-striped li {
 border:none;
 background-color: transparent;
 padding: 5px 15px;
}


h1 {
 font-size: 24px;
 line-height: 30px;
 margin: 0 0 9px 0;
}

h2 {
 font-size: 21px;
 line-height: 28px;
}

h3 {
 font-size: 19px;
 line-height: 25px;
}


h4 {
 font-size: 16px;
}

a.selected {
 color: #333;
}


/* HEADER */
/*----------------------------------- */

#logo{
  width: 150px;
  height: 35px;
  background-image: url(logo-cubicweb.svg);
  background-repeat: no-repeat;
  background-position: center bottom;
  background-size: contain;
  float: left;
}


.navbar .cw-site-title {
 font-size: 18px;
}

/* MAIN */
/*----------------------------------- */
#rqlinput {
 margin-bottom: 1em;
 }

#rql {
  width: 100%;
}

.navcontentbottom {
  margin-top: 2em;
}

div.ctxtoolbar {
  float: right;
  padding-left: 24px;
  position: relative;
}

/* FORMS  */
/*----------------------------------- */

iframe {
  border: 0;
}

label.required:after {
  content: "";
  background: url("required.png") 100% 50% no-repeat;
  padding-right: 0.8em;
}

div.notice {
  display: none;
}

/* RELEDIT FORM /
/*----------------------------------- */

/* do not remove this one */
.releditForm {
  display: none;
}

.releditField span.glyphicon {
  padding-left: 4px;
  display: inline-block;
  color: #333;
  cursor: pointer
}

.releditField span.glyphicon.glyphicon-remove {
  color: #ff0000;
 }

.releditField span.glyphicon.glyphicon-plus {
  color: #008000;
 }

div.buttonbar {
  margin-top: 0.5em;
}

/* FORM RELATIONS PART */
/*----------------------------------- */

/* bootsrap has his own definition of .invisible
   which is different of cw */

table#relatedEntities li.invisible {
  visibility: visible;
}

table#relatedEntities li.invisible div {
  display: inline;
}

table#relatedEntities th {
  background: #fff;
 }

table#relatedEntities select option {
  max-width: 500px;
}

/* VIEWS */
/*----------------------------------- */

/* PRIMARY VIEW */
/*----------------------------------- */

.cw-table-primary-entity tr:first-child th,
.cw-table-primary-entity tr:first-child td {
  border-top: none;
}

.cw-table-primary-entity th {
  background-color: inherit;
  font-weight: normal;
  color: #666
}

a.see-all:after {
  content: " \2192";
 }

/* XXX what is input-text for ??? */

/* .primary_entities li span input.input-text, */
/* .primary_entities li span textarea { */
/*   margin: 9px 0; */
/* } */

/* html input.input-text, html textarea { */
/*   width: 98%; */
/*   min-width: 150px; */
/*   margin: 2% 0 0 0; */
/* } */

/* input.input-text, textarea { */
/*   margin: 12px; */
/*   margin-left: 0; */
/*   margin-bottom: 0; */
/* } */

/* Log History UndoHistory View */
/*----------------------------------- */

ul.undo-transactions{
  background: #fff;
  color: #aaa;
}

ul.undo-transactions>li{
  margin: 1em 0;
}

ul.undo-transactions>li>a{
}

ul.undo-transactions span.undo a{
  color: orange;
  padding: 0 3px;
}

ol.undo-actions{
  margin: 0.5em auto;
  background: #F5F5F5;
  padding: 10px 15px;
  border: 1px dotted #DDDDDD;
  color: #404040;
  border-radius: 4px 4px 4px 4px;
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}

/* FACETS */
/*----------------------------------- */

div.facet {
  margin: 0px;
  padding: 0px;
  background: #fff;
  border: none;
  webkit-border-radius: 5px;
  moz-border-radius: 5px;
  border-radius: 5px;
  min-height: 20px;
  margin-bottom: 1em;
  box-shadow: none;
 }

div.facet div.facetTitle {
  background-color: #f5f5f5;
  margin: 0;
  padding: 0.2em 0.5em;
  font-weight: bold;
  border: 1px solid #dadada;
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
}

div.facet input {
  padding-top: 0.2em;
  margin-top: 0;
}

.facetBody {
  border: 1px solid #dadada;
  border-top: none;
  padding: 5px;
 }

/* has_text facet has not facetBody*/
.facet input{
  padding: 5px;
}

.facet_filterbox fieldset {
  display: table-column;
}

.facet input,
.facet textarea {
  width: 100%;
}

.facet select {
  display: none;
}

.facetValueSelected{
  background: url("img/facet_selected.png") 0% 50% no-repeat;
  font-weight: bold;
}

.facetValueDisabled span,
div.facetCheckBox span {
  opacity: .6;
  font-size: 86%;
}

div div.facetValueSelected {
  background: transparent;
}

div.facetValueSelected span {
  opacity: 1;
}

.facet-action {
  margin-bottom: 5px;
  font-size: 90%;
}


/* schema permissions view */
/*----------------------------------- */

table.schemaInfo td {
  border: 1px solid #eee;
}

/* table sortable and icons */
/*----------------------------------- */
th.sortable:hover,
th.headerSortUp,
th.headerSortDown {
  color: #428BCA;
}

th.headerSortUp {
  background-image: url("img/table_up.png");
}


th.headerSortDown {
  background-image: url("img/table_down.png");
}

/*  BUTTONS */
/*----------------------------------- */

.btn-warning a, .btn-success a,
.btn-info a {
  color: #fff;
}

button i {
 width: 23px;
}

/* MODAL DIALOG */
/*-----------------------------------*/

.modal-title {
  font-weight: bold;
  font-size: 110%;
}

/* FOOTER STYLES */
/*-----------------------------------*/
footer {
  margin-top: 4em;
  padding-bottom: 5em;
  padding-top: 2em;
  text-align: center;
}

footer#pagefooter p.copyright {
  text-align: center;
}

/* AUTOCOMPLETE FROM Jquery*/
/*----------------------------------- */

.ac_results {
  padding: 6px 0;
  overflow: hidden;
  z-index: 99999;
  list-style: none;
  background-color: #ffffff;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-right-width: 2px;
  border-bottom-width: 2px;
  -webkit-border-radius: 5px;
     -moz-border-radius: 5px;
          border-radius: 5px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
     -moz-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
          box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  -webkit-background-clip: padding-box;
     -moz-background-clip: padding;
          background-clip: padding-box;
}
.ac_results = dropdown
.ac_results  ul { /*Equals dropdown-menu css*/
    position: absolute;
    top: 100%;
    left: 0;
    z-index: 1000;
/*  display: none;*/
    float: left;
    min-width: 160px;
    width: 100%;
    list-style-position: outside;
    list-style: none;
    padding: 0;
    margin: 0;
}
.ac_results li {
    line-height: 20px;
    margin: 0px;
    padding: 2px 5px;
    cursor: default;
    display: block;
    /*
    if width will be 100% horizontal scrollbar will apear
    when scroll mode will be used
    */
    /*width: 100%;*/
    font: menu;
    /*
    it is very important, if line-height not setted or setted
    in relative units scroll will be broken in firefox
    */
    overflow: hidden;
    background-image: none;
}
.ac_loading {
    background: white url('ajax-loader.gif') 98% center no-repeat;
}
.ac_odd {
    background-color: white;
}
.ac_over {
    background-color: #0088CC;
    color: #efefef;
}

/* TABS */
/*----------------------------------- */

.entity-tabs > .tab-content {
  margin-top: 1em;
}

/* BOOTSTRAP */
/*----------------------------------- */

/* Main */
#contentmain { overflow: auto; }

/* Form */
input, select, textarea {
  color: #555555;
  background-color: #ffffff;
  border: 1px solid #cccccc;
}

.form-control { display: inline-block; width: revert; }
.form-horizontal .form-group { margin-left: 0; margin-right: 0; }
.validateButton { margin-right: 0.5em; }

/* Panel */
.panel-body, .panel-heading { padding: 6px; }
.panel-body > ul { margin: 0; }

/* Breadcrumb */
.breadcrumb {
    margin: 0;
    background: transparent;
    border-radius: 0;
}

.breadcrumb a, .breadcrumb a:hover, .breadcrumb a:active, .breadcrumb li.active,
.cw-breadcrumb ul a {
    color: inherit;
}

/* JQUERYUI */
/*----------------------------------- */

body .ui-widget {
 font-family: inherit;
 font-size: inherit;
}

/* RESPONSIVE */
/*----------------------------------- */

/* iPads (portrait and landscape) */
/*----------------------------------- */

@media only screen
and (min-device-width : 768px)
and (max-device-width : 1024px) {

  .facetFilteredBox fieldset input{
    max-width:80px;
  }
}
