h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6{margin-bottom:1rem;color:inherit;line-height:1.2}h1,.h1{font-weight:700;font-size:4.75rem}h2,.h2{font-weight:700;font-size:3.375rem}h3,.h3{font-weight:400;font-size:2.25rem}h4,.h4{font-weight:400;font-size:1.5rem}h5,.h5{font-weight:700;font-size:1rem}h6,.h6{font-weight:400;font-size:0.875rem}.nj-lead{font-weight:400;font-size:1.25rem}small,.small{font-weight:400;font-size:0.75rem}mark,.mark{padding:.2em;background-color:#f5f5f5}.list-unstyled{padding-left:0;list-style:none}.list-inline{padding-left:0;list-style:none}.list-inline-item{display:inline-block}.list-inline-item:not(:last-child){margin-right:1rem}.initialism{font-size:90%;text-transform:uppercase}.blockquote{margin-bottom:1rem;font-weight:300;font-size:1.5rem}.blockquote__icon{transform:scaleX(-1)}.blockquote__footer{display:block;font-size:1rem}
