.nj-fab{--fab-disabled-color: var(--nj-color-base-black-200);--fab-disabled-background: var(--nj-color-base-gray-200);--fab-menu-item-color: var(--nj-color-base-gray-600);--fab-menu-item-background: var(--nj-color-base-white);position:relative;z-index:var(--nj-elevation-fixed);width:4rem;min-width:4rem;height:4rem;padding:0;line-height:0;background:#fff;border:0;border-radius:50%;box-shadow:var(--nj-shadow-level-2-dp);cursor:pointer;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.3s}[data-theme="dark"] .nj-fab,.nj-fab[data-theme="dark"]{--fab-disabled-color: var(--nj-color-base-white-300);--fab-disabled-background: var(--nj-color-base-white-300);--fab-menu-item-color: var(--nj-color-text-background-light);--fab-menu-item-background: var(--nj-color-base-gray-500)}.nj-fab__actions{padding-left:0;list-style:none;position:absolute;top:0;left:0;z-index:var(--nj-elevation-dropdown);display:flex;align-items:center;justify-content:center;width:4rem;height:4rem;margin:0}.nj-fab__actions .nj-fab__item{position:absolute}.nj-fab .material-icons{color:inherit}.nj-fab--sm{width:3rem;min-width:3rem;height:3rem}.nj-fab.active{box-shadow:var(--nj-shadow-level-6-dp)}.nj-fab.active:not(.no-rotate) .material-icons{transform:rotate(-45deg)}.nj-fab--primary{color:var(--nj-color-text-background-primary);background:var(--nj-color-base-primary)}.nj-fab--primary:hover,.nj-fab--primary:focus{background:var(--nj-color-base-primary-hover)}.nj-fab--primary:not(:disabled):not(.disabled):active,.nj-fab--primary:not(:disabled):not(.disabled).active,.show>.nj-fab--primary.dropdown-toggle{color:var(--nj-color-text-background-primary);background-color:var(--nj-color-base-primary-active)}.nj-fab--success{color:var(--nj-color-text-background-success);background:var(--nj-color-base-success)}.nj-fab--success:hover,.nj-fab--success:focus{background:var(--nj-color-base-success-hover)}.nj-fab--success:not(:disabled):not(.disabled):active,.nj-fab--success:not(:disabled):not(.disabled).active,.show>.nj-fab--success.dropdown-toggle{color:var(--nj-color-text-background-success);background-color:var(--nj-color-base-success-active)}.nj-fab--warning{color:var(--nj-color-text-background-warning);background:var(--nj-color-base-warning)}.nj-fab--warning:hover,.nj-fab--warning:focus{background:var(--nj-color-base-warning-hover)}.nj-fab--warning:not(:disabled):not(.disabled):active,.nj-fab--warning:not(:disabled):not(.disabled).active,.show>.nj-fab--warning.dropdown-toggle{color:var(--nj-color-text-background-warning);background-color:var(--nj-color-base-warning-active)}.nj-fab--danger{color:var(--nj-color-text-background-danger);background:var(--nj-color-base-danger)}.nj-fab--danger:hover,.nj-fab--danger:focus{background:var(--nj-color-base-danger-hover)}.nj-fab--danger:not(:disabled):not(.disabled):active,.nj-fab--danger:not(:disabled):not(.disabled).active,.show>.nj-fab--danger.dropdown-toggle{color:var(--nj-color-text-background-danger);background-color:var(--nj-color-base-danger-active)}.nj-fab--light{color:var(--nj-color-text-background-light);background:var(--nj-color-base-light)}.nj-fab--light:hover,.nj-fab--light:focus{background:var(--nj-color-base-light-hover)}.nj-fab--light:not(:disabled):not(.disabled):active,.nj-fab--light:not(:disabled):not(.disabled).active,.show>.nj-fab--light.dropdown-toggle{color:var(--nj-color-text-background-light);background-color:var(--nj-color-base-light-active)}.nj-fab.disabled,.nj-fab:disabled{background-color:var(--fab-disabled-background);box-shadow:0 0;cursor:default}.nj-fab.disabled i,.nj-fab:disabled i{color:var(--fab-disabled-color)}.nj-fab-menu{position:relative;z-index:var(--nj-elevation-fixed)}.nj-fab-menu .nj-fab--light{color:var(--fab-menu-item-color);background-color:var(--fab-menu-item-background)}
