.nj-table{--table-background-color: transparent;--table-border-color: var(--nj-color-base-gray-300);--table-stripped-background-color: var(--nj-color-base-gray-100);--table-hoverable-background-color: var(--nj-color-base-gray-200);width:100%;margin-bottom:1rem;background-color:var(--table-background-color)}[data-theme="dark"] .nj-table,.nj-table[data-theme="dark"]{--table-background-color: var(--nj-color-background-components);--table-border-color: var(--nj-color-base-gray-400);--table-stripped-background-color: var(--nj-color-base-gray-900);--table-hoverable-background-color: var(--nj-color-base-gray-800)}.nj-table th,.nj-table td{padding:.75rem;font-weight:400;vertical-align:top;border-top:var(--nj-size-border-width) solid var(--table-border-color);font-size:0.875rem}.nj-table thead tr th{text-transform:uppercase;vertical-align:bottom;border-top-width:0;border-bottom-width:var(--nj-size-border-width);font-size:0.75rem}.nj-table tbody+tbody{border-top:calc(2 * var(--nj-size-border-width)) solid var(--table-border-color)}.nj-table--striped tbody tr:nth-of-type(odd){background-color:var(--table-stripped-background-color)}.nj-table--striped th,.nj-table--striped td{border:0}.nj-table--hover tbody tr:hover{background-color:var(--table-hoverable-background-color)}
