.nj-card{--card-details-color: var(--nj-color-base-gray-600);--card-arrow-hover: var(--nj-color-base-gray-900);position:relative;display:flex;flex-direction:column;min-width:0;color:var(--nj-color-text-body);word-wrap:break-word;background-color:var(--nj-color-background-components);box-shadow:var(--nj-shadow-level-2-dp)}[data-theme="dark"] .nj-card,.nj-card[data-theme="dark"]{--card-details-color: var(--nj-color-base-gray-300);--card-arrow-hover: var(--nj-color-base-gray-100)}.nj-card__header{display:flex;align-items:center;justify-content:center;padding:1.5rem 1.5rem;color:#fff;background-color:#009de9}.nj-card__body{flex-direction:column;padding:1.5rem}.nj-card__details{color:var(--card-details-color);font-size:0.75rem}.nj-card__title{margin-bottom:1rem;font-weight:700;font-size:1.5rem}.nj-card__subtitle{font-weight:700;font-size:1rem}.nj-card__description{margin-bottom:0}.nj-card__date{margin:auto 0 0;color:var(--card-details-color);line-height:1.5rem;text-transform:uppercase;font-size:0.75rem}.nj-card__number{font-weight:700;font-size:2.25rem}.nj-card__growth{display:flex;align-items:center;font-weight:300;font-size:1.5rem}.nj-card__img{width:100%;min-height:1px;object-fit:cover}.nj-card__overlay{display:flex;flex-direction:column;height:calc(320px - (1rem * 2));padding:0 1rem;overflow:hidden;background-color:transparent;transition:background-color 0.2s cubic-bezier(0.4, 0, 0.2, 1),padding 0.2s cubic-bezier(0.4, 0, 0.2, 1)}.nj-card--border{border:0;border-bottom:7px solid;border-image-source:var(--nj-color-base-gradient-primary);border-image-slice:1}.nj-card--horizontal{flex-direction:row;flex-wrap:wrap}.nj-card--horizontal .nj-card__img{width:253px;height:175px}@media (max-width: 575.98px){.nj-card--horizontal .nj-card__img{width:100%}}.nj-card--cover{height:320px;overflow:hidden;background-repeat:no-repeat;background-position:center;background-size:cover;box-shadow:none}.nj-card--cover .nj-card__body{position:relative;padding:1rem}.nj-card--cover .nj-card__title{padding-right:.5rem;color:#fff;transform:translateY(calc(320px - (1rem * 3) - 100%))}.nj-card--cover .nj-card__description{transform:translateY(320px)}.nj-card--cover .material-icons{position:absolute;right:1rem;bottom:1rem;z-index:0;color:#fff;transition:all 0.3s cubic-bezier(0.4, 0, 0.2, 1)}@media (hover: hover){.nj-card--cover.nj-card:hover{box-shadow:none}.nj-card--cover.nj-card:hover .nj-card__title,.nj-card--cover.nj-card:hover .nj-card__description{color:var(--nj-color-text-body);transform:translateY(0);transition:all 0.5s cubic-bezier(0.4, 0, 0.2, 1)}.nj-card--cover.nj-card:hover .material-icons{right:calc(1.5rem + 4px);bottom:calc(1.5rem + 4px);color:var(--card-arrow-hover)}.nj-card--cover.nj-card:hover .nj-card__overlay{padding:2rem 1rem;background-color:var(--nj-color-background-components)}}a.nj-card{color:inherit;text-decoration:none;transition-property:box-shadow;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.3s}a.nj-card:hover{color:inherit;text-decoration:none;box-shadow:var(--nj-shadow-level-8-dp)}.nj-card-deck{display:flex;flex-direction:column}.nj-card-deck .nj-card{margin-bottom:1rem}@media (min-width: 576px){.nj-card-deck{flex-flow:row wrap;margin-right:-1rem;margin-left:-1rem}.nj-card-deck .nj-card{display:flex;flex:1 0 0%;flex-direction:column;margin-right:1rem;margin-bottom:0;margin-left:1rem}}.nj-card-columns .nj-card{margin-bottom:1rem}@media (min-width: 576px){.nj-card-columns{column-count:3;column-gap:1.25rem;orphans:1;widows:1}.nj-card-columns .nj-card{display:inline-block;width:100%}}
