.nj-switch{--switch-checked-part-color: var(--nj-color-text-body-inverted);--switch-unchecked-part-color: var(--nj-color-base-primary);--switch-checked-part-color-disabled: var(--nj-color-base-gray-200);--switch-unchecked-part-color-disabled: var(--nj-color-base-gray-400);--switch-ckecked-background-color-disabled: var(--nj-color-base-gray-400);--switch-unckecked-background-color-disabled: var(--nj-color-base-gray-200);--switch-slider-color: var(--nj-color-base-gray-200)}[data-theme="dark"] .nj-switch,.nj-switch[data-theme="dark"]{--switch-checked-part-color-disabled: var(--nj-color-base-gray-300);--switch-unchecked-part-color-disabled: var(--nj-color-base-gray-400);--switch-ckecked-background-color-disabled: var(--nj-color-base-gray-400);--switch-unckecked-background-color-disabled: var(--nj-color-base-gray-500);--switch-slider-color: var(--nj-color-base-gray-800)}.nj-switch__slider{position:relative;z-index:1;display:flex;height:2rem;overflow:hidden;background-color:var(--switch-slider-color);border-radius:6.25rem;cursor:pointer;transition:0.2s}@media screen and (prefers-reduced-motion: reduce){.nj-switch__slider{transition:none}}.nj-switch__slider-left,.nj-switch__slider-right{position:relative;padding:0 1rem;font-weight:700;font-size:13px;line-height:2rem;transition:0.4s}@media screen and (prefers-reduced-motion: reduce){.nj-switch__slider-left,.nj-switch__slider-right{transition:none}}.nj-switch__slider-left::before,.nj-switch__slider-right::before{position:absolute;top:0;left:0;z-index:-1;width:100%;height:2rem;background:var(--nj-color-base-primary);border-radius:6.25rem;content:"";transition:0.2s}@media screen and (prefers-reduced-motion: reduce){.nj-switch__slider-left::before,.nj-switch__slider-right::before{transition:none}}.nj-switch__slider-left i,.nj-switch__slider-right i{color:inherit;line-height:inherit}.nj-switch__slider-left{color:var(--switch-checked-part-color)}.nj-switch__slider-right{color:var(--switch-unchecked-part-color)}.nj-switch__slider-right::before{left:-100%}.nj-switch input{position:absolute;display:block;width:0;height:0;opacity:0}.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-left,.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-right{color:var(--switch-unchecked-part-color)}.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-left::before,.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-right::before{left:100%}.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-right{color:var(--switch-checked-part-color)}.nj-switch input:checked+.nj-switch__slider .nj-switch__slider-right::before{left:0}.nj-switch input:disabled+.nj-switch__slider{background-color:var(--switch-unckecked-background-color-disabled);cursor:not-allowed}.nj-switch input:disabled+.nj-switch__slider .nj-switch__slider-left::before,.nj-switch input:disabled+.nj-switch__slider .nj-switch__slider-right::before{background:var(--switch-ckecked-background-color-disabled)}.nj-switch input:disabled+.nj-switch__slider .nj-switch__slider-left{color:var(--switch-checked-part-color-disabled)}.nj-switch input:disabled+.nj-switch__slider .nj-switch__slider-right{color:var(--switch-unchecked-part-color-disabled)}.nj-switch input:disabled:checked+.nj-switch__slider .nj-switch__slider-left{color:var(--switch-unchecked-part-color-disabled)}.nj-switch input:disabled:checked+.nj-switch__slider .nj-switch__slider-right{color:var(--switch-checked-part-color-disabled)}.nj-switch--primary .nj-switch__slider-left::before,.nj-switch--primary .nj-switch__slider-right::before{background:var(--nj-color-base-primary)}.nj-switch--primary .nj-switch__slider-right{color:var(--nj-color-base-primary)}.nj-switch--primary input:checked+.nj-switch__slider .nj-switch__slider-left{color:var(--nj-color-base-primary)}.nj-switch--success .nj-switch__slider-left::before,.nj-switch--success .nj-switch__slider-right::before{background:var(--nj-color-base-success)}.nj-switch--success .nj-switch__slider-right{color:var(--nj-color-base-success)}.nj-switch--success input:checked+.nj-switch__slider .nj-switch__slider-left{color:var(--nj-color-base-success)}.nj-switch--warning .nj-switch__slider-left::before,.nj-switch--warning .nj-switch__slider-right::before{background:var(--nj-color-base-warning)}.nj-switch--warning .nj-switch__slider-right{color:var(--nj-color-base-warning)}.nj-switch--warning input:checked+.nj-switch__slider .nj-switch__slider-left{color:var(--nj-color-base-warning)}.nj-switch--danger .nj-switch__slider-left::before,.nj-switch--danger .nj-switch__slider-right::before{background:var(--nj-color-base-danger)}.nj-switch--danger .nj-switch__slider-right{color:var(--nj-color-base-danger)}.nj-switch--danger input:checked+.nj-switch__slider .nj-switch__slider-left{color:var(--nj-color-base-danger)}
