.bg-blue-allports{background-color:var(--nj-color-base-blue-allports) !important}.bg-blue-corporate{background-color:var(--nj-color-base-blue-corporate) !important}.bg-white{background-color:var(--nj-color-base-white) !important}.bg-green-java{background-color:var(--nj-color-base-green-java) !important}.bg-orange-crusta{background-color:var(--nj-color-base-orange-crusta) !important}.bg-purple{background-color:var(--nj-color-base-purple) !important}.bg-red-mandy{background-color:var(--nj-color-base-red-mandy) !important}.bg-yellow-bright-sun{background-color:var(--nj-color-base-yellow-bright-sun) !important}.bg-red{background-color:var(--nj-color-base-red) !important}.bg-green{background-color:var(--nj-color-base-green) !important}.bg-orange{background-color:var(--nj-color-base-orange) !important}.bg-blue-bigstone{background-color:var(--nj-color-base-blue-bigstone) !important}.bg-blue-rhino{background-color:var(--nj-color-base-blue-rhino) !important}.bg-blue-venice{background-color:var(--nj-color-base-blue-venice) !important}.bg-cerise{background-color:var(--nj-color-base-cerise) !important}.bg-green-fun{background-color:var(--nj-color-base-green-fun) !important}.bg-green-pine{background-color:var(--nj-color-base-green-pine) !important}.bg-green-riogrande{background-color:var(--nj-color-base-green-riogrande) !important}.bg-violet-eggplant{background-color:var(--nj-color-base-violet-eggplant) !important}.bg-violet{background-color:var(--nj-color-base-violet) !important}.bg-yellow{background-color:var(--nj-color-base-yellow) !important}.bg-primary{background-color:var(--nj-color-base-primary) !important}.bg-success{background-color:var(--nj-color-base-success) !important}.bg-warning{background-color:var(--nj-color-base-warning) !important}.bg-danger{background-color:var(--nj-color-base-danger) !important}.bg-light{background-color:var(--nj-color-base-light) !important}.bg-gray-100{background-color:var(--nj-color-base-gray-100) !important}.bg-gray-200{background-color:var(--nj-color-base-gray-200) !important}.bg-gray-300{background-color:var(--nj-color-base-gray-300) !important}.bg-gray-400{background-color:var(--nj-color-base-gray-400) !important}.bg-gray-500{background-color:var(--nj-color-base-gray-500) !important}.bg-gray-600{background-color:var(--nj-color-base-gray-600) !important}.bg-gray-700{background-color:var(--nj-color-base-gray-700) !important}.bg-gray-800{background-color:var(--nj-color-base-gray-800) !important}.bg-gray-900{background-color:var(--nj-color-base-gray-900) !important}.bg-gray-light-100{background-color:#f5f5f5 !important}.bg-gray-light-200{background-color:#eee !important}.bg-gray-light-300{background-color:#e0e0e0 !important}.bg-gray-light-400{background-color:#bdbdbd !important}.bg-gray-light-500{background-color:#9e9e9e !important}.bg-gray-light-600{background-color:#757575 !important}.bg-gray-light-700{background-color:#616161 !important}.bg-gray-light-800{background-color:#424242 !important}.bg-gray-light-900{background-color:#212121 !important}.bg-gray-dark-100{background-color:#e0e0e0 !important}.bg-gray-dark-200{background-color:#b8bfc3 !important}.bg-gray-dark-300{background-color:#758590 !important}.bg-gray-dark-400{background-color:#485d6c !important}.bg-gray-dark-500{background-color:#304759 !important}.bg-gray-dark-600{background-color:#1a3447 !important}.bg-gray-dark-700{background-color:#142938 !important}.bg-gray-dark-800{background-color:#0f1e29 !important}.bg-gray-dark-900{background-color:#081016 !important}.bg-gradient-primary{background:linear-gradient(135deg, #0af 0%, #23d2b5 100%)}.bg-transparent{background-color:transparent !important}
