.nj-dropdown{position:relative;display:block;width:100%;height:2.5rem;padding-right:1.5625rem;background:no-repeat bottom,50% calc(100% - 1px);background-image:linear-gradient(to top, var(--nj-color-text-label-focus) 2px, transparent 2px),linear-gradient(to top, var(--nj-color-border-input) 1px, transparent 1px);background-size:0 100%, 100% 100%;outline:0;cursor:pointer;transition:background 0s ease-out}@media screen and (prefers-reduced-motion: reduce){.nj-dropdown{transition:none}}.nj-dropdown.nj-dropdown--shown-collapse{background-size:100% 100%, 100% 100%;transition-duration:.3s}.nj-dropdown.nj-dropdown--shown-collapse .nj-dropdown__label,.nj-dropdown[data-selected-content] .nj-dropdown__label{bottom:30px;color:var(--nj-color-text-label-focus);font-size:0.75rem}.nj-dropdown::before{position:absolute;bottom:.625rem;color:var(--nj-color-placeholder-input-focus);font-size:1rem;line-height:1rem;content:attr(data-selected-content)}.nj-dropdown::after{position:absolute;right:.625rem;bottom:.875rem;display:inline-block;padding:.25rem;border:solid var(--nj-color-icon-input);border-width:0 .125rem .125rem 0;transform:rotate(45deg);content:""}.nj-dropdown__label{position:absolute;bottom:.625rem;color:var(--nj-color-placeholder-input-hover);line-height:1rem;white-space:nowrap;transition:0.3s ease all}@media screen and (prefers-reduced-motion: reduce){.nj-dropdown__label{transition:none}}.nj-dropdown__list{position:absolute;top:3rem;z-index:var(--nj-elevation-dropdown);width:100%}.nj-dropdown__list .nj-list-group{--list-group-hover-color: var(--nj-color-base-gray-100)}[data-theme="dark"] .nj-dropdown__list .nj-list-group,.nj-dropdown__list .nj-list-group[data-theme="dark"]{--list-group-hover-color: var(--nj-color-base-gray-900)}.nj-dropdown__list .nj-list-group button.nj-list-group__item:hover{color:inherit}
