.nj-tab{--nj-color-line-tab: var(--nj-color-base-gray-300)}[data-theme="dark"] .nj-tab,.nj-tab[data-theme="dark"]{--nj-color-line-tab: var(--nj-color-base-gray-400)}.nj-tab__items{display:flex;flex:1 0 auto;justify-content:left;width:100%;margin:0;overflow-y:auto;padding-left:0;list-style:none;border-bottom:var(--nj-size-border-width) solid var(--nj-color-line-tab)}.nj-tab__item{position:relative;display:flex;align-items:flex-end;max-width:15rem;padding:var(--nj-size-space-1) var(--nj-size-space-3);color:var(--nj-color-text-body);background-color:transparent;border:none;outline:none;cursor:pointer;transition-property:color;transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.3s}.nj-tab__item:nth-last-child(n+2){margin-right:var(--nj-size-space-3)}.nj-tab__item:after{position:absolute;bottom:0;left:0;width:100%;height:.125rem;background:var(--nj-color-base-primary);opacity:0;transition-property:opacity;content:"";transition-timing-function:cubic-bezier(0.4, 0, 0.2, 1);transition-duration:.3s}.nj-tab__item--active{font-weight:var(--nj-weight-font-bold)}.nj--use-tab .nj-tab__item--focus{background-color:var(--nj-color-background-components-active)}.nj-tab__item--active,.nj-tab__item:hover,.nj-tab__item:focus{color:var(--nj-color-text-body);text-decoration:none}.nj-tab__item--active::after,.nj-tab__item:hover::after,.nj-tab__item:focus::after{opacity:1}.nj-tab__item[disabled]{color:var(--nj-color-base-disabled);cursor:default;pointer-events:none}.nj-tab__content{display:none}.nj-tab__content--active{display:block}
