.nj-breadcrumb{--breadcrumb-separator-color: var(--nj-color-base-gray-500);display:flex;flex-wrap:wrap;margin:2rem 0;padding:0;list-style:none;font-size:0.875rem}[data-theme="dark"] .nj-breadcrumb,.nj-breadcrumb[data-theme="dark"]{--breadcrumb-separator-color: var(--nj-color-base-gray-300)}.nj-breadcrumb__item+.nj-breadcrumb__item{padding-left:.5rem}.nj-breadcrumb__item+.nj-breadcrumb__item::before{display:inline-block;padding-right:.5rem;color:var(--breadcrumb-separator-color);content:"/"}.nj-breadcrumb__item a{color:inherit;transition:inherit}.nj-breadcrumb__item a:hover{transition:color 0.15s;color:var(--nj-color-base-primary)}@media screen and (prefers-reduced-motion: reduce){.nj-breadcrumb__item a:hover{transition:none}}.nj-breadcrumb__item+.nj-breadcrumb__item:hover::before{text-decoration:underline}.nj-breadcrumb__item+.nj-breadcrumb__item:hover::before{text-decoration:none}
