.nj-radio{--radio-border-color: var(--nj-color-base-gray-600);position:relative;padding-left:2.25rem}[data-theme="dark"] .nj-radio,.nj-radio[data-theme="dark"]{--radio-border-color: var(--nj-color-base-gray-100)}.nj-radio__decorator{position:absolute;top:.125rem;left:0;display:inline-block;margin:-0.5rem -1rem;padding:0.5rem 1rem;line-height:.7;border-radius:100%}.nj-radio__decorator::after{display:inline-block;width:1.25rem;height:1.25rem;border:0.125rem solid var(--radio-border-color);border-radius:50%;cursor:pointer;content:"";transition:border-color ease 0.2s}@media screen and (prefers-reduced-motion: reduce){.nj-radio__decorator::after{transition:none}}.nj-radio__decorator::before{position:absolute;display:inline-block;width:1.25rem;height:1.25rem;background-color:var(--nj-color-base-primary);border-radius:50%;transform:scale3d(0, 0, 0);content:"";transition:transform ease 0.28s}@media screen and (prefers-reduced-motion: reduce){.nj-radio__decorator::before{transition:none}}.nj-radio label{cursor:pointer}.nj-radio input[type="radio"]{position:absolute;left:0;z-index:-1;width:0;height:0;margin:0;overflow:hidden;opacity:0;pointer-events:none}.nj-radio input[type="radio"]:checked+.nj-radio__decorator::after{border-color:var(--nj-color-base-primary)}.nj-radio input[type="radio"]:checked+.nj-radio__decorator::before{background-color:var(--nj-color-base-primary)}.nj-radio input[type="radio"]:checked+.nj-radio__decorator::before{transform:scale3d(0.5, 0.5, 1)}.nj-radio input[type="radio"]:invalid+.nj-radio__decorator::after,.has-danger .nj-radio input[type="radio"]+.nj-radio__decorator::after{border-color:#c03}.nj-radio input[type="radio"]:invalid+.nj-radio__decorator::before,.has-danger .nj-radio input[type="radio"]+.nj-radio__decorator::before{background-color:#c03}.has-warning .nj-radio input[type="radio"]+.nj-radio__decorator::after{border-color:#e07602}.has-warning .nj-radio input[type="radio"]+.nj-radio__decorator::before{background-color:#e07602}.has-success .nj-radio input[type="radio"]+.nj-radio__decorator::after{border-color:#009934}.has-success .nj-radio input[type="radio"]+.nj-radio__decorator::before{background-color:#009934}.nj-radio input[type="radio"][disabled]+.nj-radio__decorator::after,.nj-radio input[type="radio"]:disabled+.nj-radio__decorator::after,fieldset[disabled] .nj-radio input[type="radio"]+.nj-radio__decorator::after{border-color:var(--nj-color-base-disabled)}.nj-radio input[type="radio"][disabled]+.nj-radio__decorator::before,.nj-radio input[type="radio"]:disabled+.nj-radio__decorator::before,fieldset[disabled] .nj-radio input[type="radio"]+.nj-radio__decorator::before{background-color:var(--nj-color-base-disabled)}.nj-radio input[type="radio"][disabled]+.nj-radio__decorator::after,.nj-radio input[type="radio"]:disabled+.nj-radio__decorator::after,fieldset[disabled] .nj-radio input[type="radio"]+.nj-radio__decorator::after{cursor:not-allowed}.nj-radio--disabled label{color:var(--nj-color-base-disabled);cursor:not-allowed}.nj-radio--inline{display:inline-flex;margin-right:1.5rem}
