.material-icons{color:#757575}.material-icons-text{display:flex;align-items:center}.material-icons-text .material-icons{margin-right:.5rem}.material-icons.md-18{font-size:1.125rem}.material-icons.md-24{font-size:1.5rem}.material-icons.md-36{font-size:2.25rem}.material-icons.md-48{font-size:48px}.material-icons.md--blue-allports{color:#0b74c0}.material-icons.md--blue-corporate{color:#009de9}.material-icons.md--white{color:#fff}.material-icons.md--green-java{color:#6ed2b1}.material-icons.md--orange-crusta{color:#f78a31}.material-icons.md--purple{color:#1f106d}.material-icons.md--red-mandy{color:#e74a50}.material-icons.md--yellow-bright-sun{color:#fbdb3c}.material-icons.md--red{color:#c03}.material-icons.md--green{color:#009934}.material-icons.md--orange{color:#e07602}.material-icons.md--blue-bigstone{color:#0f1e29}.material-icons.md--blue-rhino{color:#2b485c}.material-icons.md--blue-venice{color:#005288}.material-icons.md--cerise{color:#e62b87}.material-icons.md--green-fun{color:#69af23}.material-icons.md--green-pine{color:#007873}.material-icons.md--green-riogrande{color:#becd00}.material-icons.md--violet-eggplant{color:#910f7d}.material-icons.md--violet{color:#552382}.material-icons.md--yellow{color:#faca08}.material-icons.md--primary{color:#009de9}.material-icons.md--success{color:#009934}.material-icons.md--warning{color:#e07602}.material-icons.md--danger{color:#c03}.material-icons.md--light{color:#fff}.material-icons.md--on-primary{color:var(--nj-color-text-background-base)}.material-icons.md--on-success{color:var(--nj-color-text-background-base)}.material-icons.md--on-warning{color:var(--nj-color-text-background-base)}.material-icons.md--on-danger{color:var(--nj-color-text-background-base)}.material-icons.md--on-light{color:var(--nj-color-text-background-light)}
