.nj-footer{--footer-bg-color:var(--nj-color-base-gray-100);background-color:var(--footer-bg-color)}[data-theme="dark"] .nj-footer,.nj-footer[data-theme="dark"]{--footer-bg-color:var(--nj-color-base-gray-700)}.nj-footer::after{display:block;width:100%;height:3px;background:linear-gradient(135deg, #0af 0%, #23d2b5 100%);content:""}.nj-footer__links{padding:0;column-count:2;list-style:none}@media (min-width: 576px){.nj-footer__links{column-count:3}}@media (min-width: 768px){.nj-footer__links{display:flex;align-items:center;justify-content:space-between;padding:0 1rem}}.nj-footer__link{color:var(--nj-color-text-body);font-weight:400;line-height:1.75rem;transition:0.15s color;font-size:0.875rem}@media screen and (prefers-reduced-motion: reduce){.nj-footer__link{transition:none}}.nj-footer__link:hover{color:var(--nj-color-base-blue-corporate);text-decoration:none}.nj-footer__social{display:flex;align-items:center;justify-content:center;padding:0;list-style:none}@media (max-width: 767.98px){.nj-footer__social{justify-content:start}}.nj-footer__social-link{display:block;margin-right:1rem}@media (min-width: 768px){.nj-footer__social-icon{width:16px;height:16px}}.nj-footer__baseline{padding:2rem 0;font-weight:700;font-size:1.5rem}@media (min-width: 768px){.nj-footer__baseline{display:flex;align-items:baseline;justify-content:center;padding:4rem}}.nj-footer__logo{display:block;margin-right:4rem;margin-bottom:1.5rem}@media (min-width: 768px){.nj-footer__logo{margin-bottom:0}}@media (max-width: 991.98px){.nj-footer__logo{width:90px}}
