.nj-tooltip{--tooltip-text: var(--nj-color-base-white);--tooltip-bg: var(--nj-color-base-blue-bigstone);position:absolute;z-index:var(--nj-elevation-tooltip);display:block;margin:0;font-weight:400;font-family:"Lato",-apple-system,"BlinkMacSystemFont","Segoe UI","Roboto","Helvetica Neue","Arial",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";font-style:normal;line-height:1.5;letter-spacing:normal;white-space:normal;text-align:left;text-align:start;text-transform:none;text-decoration:none;text-shadow:none;word-break:normal;word-spacing:normal;line-break:auto;font-size:0.75rem;word-wrap:break-word;opacity:0}[data-theme="dark"] .nj-tooltip,.nj-tooltip[data-theme="dark"]{--tooltip-text: var(--nj-color-base-gray-100);--tooltip-bg: var(--nj-color-base-gray-500)}.nj-tooltip.show{opacity:1}.nj-tooltip.nj-tooltip--without-arrow .nj-tooltip__arrow{display:none}.nj-tooltip.nj-tooltip--top,.nj-tooltip.nj-tooltip--auto[x-placement^="top"]{padding:.4rem 0}.nj-tooltip.nj-tooltip--top .nj-tooltip__arrow,.nj-tooltip.nj-tooltip--auto[x-placement^="top"] .nj-tooltip__arrow{bottom:0}.nj-tooltip.nj-tooltip--top .nj-tooltip__arrow::before,.nj-tooltip.nj-tooltip--auto[x-placement^="top"] .nj-tooltip__arrow::before{top:0;border-width:.4rem .4rem 0;border-top-color:var(--tooltip-bg)}.nj-tooltip.nj-tooltip--right,.nj-tooltip.nj-tooltip--auto[x-placement^="right"]{padding:0 .4rem}.nj-tooltip.nj-tooltip--right .nj-tooltip__arrow,.nj-tooltip.nj-tooltip--auto[x-placement^="right"] .nj-tooltip__arrow{left:0;width:.4rem;height:.8rem}.nj-tooltip.nj-tooltip--right .nj-tooltip__arrow::before,.nj-tooltip.nj-tooltip--auto[x-placement^="right"] .nj-tooltip__arrow::before{right:0;border-width:.4rem .4rem .4rem 0;border-right-color:var(--tooltip-bg)}.nj-tooltip.nj-tooltip--bottom,.nj-tooltip.nj-tooltip--auto[x-placement^="bottom"]{padding:.4rem 0}.nj-tooltip.nj-tooltip--bottom .nj-tooltip__arrow,.nj-tooltip.nj-tooltip--auto[x-placement^="bottom"] .nj-tooltip__arrow{top:0}.nj-tooltip.nj-tooltip--bottom .nj-tooltip__arrow::before,.nj-tooltip.nj-tooltip--auto[x-placement^="bottom"] .nj-tooltip__arrow::before{bottom:0;border-width:0 .4rem .4rem;border-bottom-color:var(--tooltip-bg)}.nj-tooltip.nj-tooltip--left,.nj-tooltip.nj-tooltip--auto[x-placement^="left"]{padding:0 .4rem}.nj-tooltip.nj-tooltip--left .nj-tooltip__arrow,.nj-tooltip.nj-tooltip--auto[x-placement^="left"] .nj-tooltip__arrow{right:0;width:.4rem;height:.8rem}.nj-tooltip.nj-tooltip--left .nj-tooltip__arrow::before,.nj-tooltip.nj-tooltip--auto[x-placement^="left"] .nj-tooltip__arrow::before{left:0;border-width:.4rem 0 .4rem .4rem;border-left-color:var(--tooltip-bg)}.nj-tooltip .nj-tooltip__arrow{position:absolute;display:block;width:.8rem;height:.4rem}.nj-tooltip .nj-tooltip__arrow::before{position:absolute;border-color:transparent;border-style:solid;content:""}.nj-tooltip .nj-tooltip__inner{max-width:200px;padding:.25rem .75rem;color:var(--tooltip-text);text-align:center;background-color:var(--tooltip-bg)}
