!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define("NJ_autoInit",[],t):"object"==typeof exports?exports.NJ_autoInit=t():e.NJ_autoInit=t()}(window,(function(){return function(e){var t={};function o(n){if(t[n])return t[n].exports;var r=t[n]={i:n,l:!1,exports:{}};return e[n].call(r.exports,r,r.exports,o),r.l=!0,r.exports}return o.m=e,o.c=t,o.d=function(e,t,n){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:n})},o.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(e,t){if(1&t&&(e=o(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var n=Object.create(null);if(o.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)o.d(n,r,function(t){return e[t]}.bind(null,r));return n},o.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="",o(o.s=0)}([function(e,t,o){"use strict";o.r(t);var n=["Alert","Checkbox","Collapse","Dropdown","Fab","Form","Header","Modal","Navbar","Radio","Select","Sidebar","Slider","Tab","Tag","Tooltip"],r=function(){if("undefined"!=typeof window){function e(){if(window.NJ)window.NJ.AutoInit();else for(var e=n.length,t=0;t<e;t++)window[n[t]]&&window[n[t]].init()}function t(e){if(e&&e.getAttribute&&"tooltip"===e.getAttribute("data-toggle")){var t=window.Tooltip||window.NJ.Tooltip;return t&&new t(e),!0}return!1}document.addEventListener("DOMContentLoaded",(function(){e();for(var o=document.querySelectorAll('[data-toggle="tooltip"]'),n=0;n<o.length;n++)t(o[n]);var r=document.getElementById("root");if(r){new MutationObserver((function(o){for(var n=0,r=o.length;n<r;n++){if("childList"===o[n].type&&o[n].addedNodes.length){for(var i=!1,d=0;d<o[n].addedNodes.length;d++){var u=o[n].addedNodes[d],a=u.parentNode,f=a.parentNode;if(!u.key&&!a.key&&!f.key)t(o[n].addedNodes[d])||(i=!0)}i&&e()}if("childList"===o[n].type&&o[n].removedNodes.length)for(var l=0;l<o[n].removedNodes.length;l++){var c=o[n].removedNodes[l];c.key&&c.key&&window.NJStore[c.key.id].dispose()}}})).observe(r,{attributes:!1,childList:!0,subtree:!0})}}))}}();t.default=r}]).default}));